@@ -6,7 +6,11 @@ import jinja2
 
 import logging
 
-def create_app(Database):
+from realnet.core.config import Config
+from .auth import config_oauth
+from .router import router_bp
+
+def create_app(contextProvider):
     logging.basicConfig(level=logging.DEBUG)
 
     cfg = Config()
@@ -16,25 +20,19 @@ def create_app(Database):
     # import realnet_server.wsgi
 
     app.secret_key = cfg.get_app_secret()
-    app.config['SQLALCHEMY_DATABASE_URI'] = cfg.get_database_url()
-    app.config['SQLALCHEMY_ECHO'] = True
-    app.config['GOOGLE_CLIENT_ID'] = ''
-    app.config['GOOGLE_CLIENT_SECRET'] = ''
     app.config['BOOTSTRAP_SERVE_LOCAL'] = True
+    app.config['REALNET_CONTEXT_PROVIDER'] = contextProvider
 
 
     app.jinja_loader = jinja2.ChoiceLoader([
         app.jinja_loader,
-        jinja2.PackageLoader(__name__) # in the same folder will search the 'templates' folder
+        jinja2.PackageLoader('realnet') # in the same folder will search the 'templates' folder
     ])
-    Database.init_app(app)
-
+    
     bootstrap = Bootstrap(app)
 
     config_oauth(app)
 
-    
-
     app.register_blueprint(router_bp)
 
     return app
\ No newline at end of file
